@@ -17,6 +17,7 @@ import uuid
 
 import cirq
 import pytest
+import sympy
 from iqm_client.iqm_client import (IQMClient, RunResult, RunStatus,
                                    SingleQubitMapping)
 from mockito import ANY, mock, when
@@ -72,8 +73,8 @@ def test_serialize_qubit_mapping(qubit_mapping):
 def test_run_sweep_executes_circuit(adonis_sampler, circuit):
     client = mock(IQMClient)
     run_id = uuid.uuid4()
-    run_result = RunResult(status=RunStatus.READY, measurements={'some stuff': [[0], [1]]}, message=None)
-    when(client).submit_circuit(ANY, ANY, ANY).thenReturn(run_id)
+    run_result = RunResult(status=RunStatus.READY, measurements=[{'some stuff': [[0], [1]]}], message=None)
+    when(client).submit_circuits(ANY, ANY, ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
 
     adonis_sampler._client = client
@@ -85,14 +86,35 @@ def test_run_sweep_executes_circuit(adonis_sampler, circuit):
 def test_run_sweep_executes_circuit_without_settings(adonis_sampler_without_settings, circuit_with_physical_names):
     client = mock(IQMClient)
     run_id = uuid.uuid4()
-    run_result = RunResult(status=RunStatus.READY, measurements={'some stuff': [[0], [1]]}, message=None)
-    when(client).submit_circuit(ANY, ANY, ANY).thenReturn(run_id)
+    run_result = RunResult(status=RunStatus.READY, measurements=[{'some stuff': [[0], [1]]}], message=None)
+    when(client).submit_circuits(ANY, ANY, ANY).thenReturn(run_id)
     when(client).wait_for_results(run_id).thenReturn(run_result)
 
     adonis_sampler_without_settings._client = client
     results = adonis_sampler_without_settings.run_sweep(circuit_with_physical_names, None, repetitions=2)
     assert isinstance(results[0], cirq.Result)
 
+@pytest.mark.usefixtures('unstub')
+def test_run_sweep_with_parameter_sweep(adonis_sampler_without_settings):
+    client = mock(IQMClient)
+    run_id = uuid.uuid4()
+    run_result = RunResult(
+        status=RunStatus.READY, measurements=[{'some stuff': [[0]]}, {'some stuff': [[1]]}], message=None
+    )
+    when(client).submit_circuits(ANY, ANY, ANY).thenReturn(run_id)
+    when(client).wait_for_results(run_id).thenReturn(run_result)
+    qubit_1 = cirq.NamedQubit('QB1')
+    qubit_2 = cirq.NamedQubit('QB2')
+    circuit_sweep = cirq.Circuit(cirq.X(qubit_1) ** sympy.Symbol('t'), cirq.measure(qubit_1, qubit_2, key='result'))
+
+    sweep_length = 2
+    param_sweep = cirq.Linspace('t', start=0, stop=1, length=sweep_length)
+
+    adonis_sampler_without_settings._client = client
+
+    results = adonis_sampler_without_settings.run_sweep(circuit_sweep, param_sweep, repetitions=123)
+    assert len(results) == sweep_length
+    assert all(isinstance(result, cirq.Result) for result in results)
 
 def test_credentials_are_passed_to_client(settings_dict):
     user_auth_args = {
